package
Version:
v0.0.0-...-e5f8ed5
Opens a new window with list of versions in this module.
Published: Mar 3, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Host string `default:"localhost"`
Port int `default:"3000"`
Sentry Sentry
}
Config captures generic information for testing purposes
Sentry captures config related to Sentry logging for testing purposes
Source Files
¶
Click to show internal directories.
Click to hide internal directories.