bq

package
v0.0.0-...-e5f8ed5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2023 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DatasetFromProject

func DatasetFromProject(bqConfig *config.BQConfig, project string) string

DatasetFromProject create BQ dataset name from a project and prefix it with the BQConfig.BQDatasetPrefix

func TableFromKafkaTopic

func TableFromKafkaTopic(kafkaTopic string) string

TableFromKafkaTopic create BQ table name from a given kafka topic.

func TableFromObservationService

func TableFromObservationService(bqConfig *config.BQConfig, observationServiceName string) string

TableFromObservationService create BQ table name from observation service name and prefix it with BQConfig.ObservationBQTablePrefix

Types

This section is empty.

Jump to