Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Client ¶
type Client interface {
// ReadChart read a helm chart given by the chart path.
ReadChart(chartPath string) (*chart.Chart, error)
// InstallOrUpgrade upgrades an existing helm release or install a new one.
InstallOrUpgrade(release string, ns string, chart *chart.Chart, values map[string]any, actionConfig *action.Configuration) (*release.Release, error)
// Uninstall uninstalls an existing helm release.
Uninstall(release string, ns string, actionConfig *action.Configuration) error
}
Client is interface for a helm client
Click to show internal directories.
Click to hide internal directories.